@@ -1,13 +1,13 @@
 from .itertoolz import (groupby, countby, frequencies, reduceby,
                         first, second, nth, take, drop, rest, last,
                         get, merge_sorted, concat, concatv, mapcat,
-                        isdistinct, interleave, unique, intersection,
+                        isdistinct, interleave, interpose, unique,
                         isiterable, remove, iterate, accumulate,
                         partitionby, partition, partition_all,
-                        sliding_window, count)
+                        sliding_window, count, cons, take_nth)
 
 from .functoolz import (memoize, curry, compose, thread_first,
-                        thread_last, identity, pipe)
+                        thread_last, identity, pipe, complement)
 
 from .dicttoolz import merge, merge_with, keymap, valmap, assoc, update_in
 
@@ -22,4 +22,4 @@ sorted = sorted
 # Aliases
 comp = compose
 
-__version__ = '0.4.1'
+__version__ = '0.5.0'
