@@ -8,7 +8,7 @@ from toolz.compatibility import map, filter, zip, zip_longest
 identity = lambda x: x
 
 
-def remove(predicate, coll):
+def remove(predicate, seq):
     """ Return those items of collection for which predicate(item) is true.
 
     >>> def iseven(x):
@@ -16,11 +16,11 @@ def remove(predicate, coll):
     >>> list(remove(iseven, [1, 2, 3, 4]))
     [1, 3]
     """
-    return filter(lambda x: not predicate(x), coll)
+    return filter(lambda x: not predicate(x), seq)
 
 
 def accumulate(binop, seq):
-    """ Repeatedly apply binary function f to a sequence, accumulating results
+    """ Repeatedly apply binary function to a sequence, accumulating results
 
     >>> from operator import add, mul
     >>> list(accumulate(add, [1, 2, 3, 4, 5]))
@@ -38,15 +38,15 @@ def accumulate(binop, seq):
     See Also:
         itertools.accumulate :  In standard itertools for Python 3.2+
     """
-    coll = iter(seq)
-    result = next(coll)
+    seq = iter(seq)
+    result = next(seq)
     yield result
-    for elem in coll:
+    for elem in seq:
         result = binop(result, elem)
         yield result
 
 
-def groupby(f, coll):
+def groupby(func, seq):
     """ Group a collection by a key function
 
     >>> names = ['Alice', 'Bob', 'Charlie', 'Dan', 'Edith', 'Frank']
@@ -61,15 +61,15 @@ def groupby(f, coll):
         ``countby``
     """
     d = dict()
-    for item in coll:
-        key = f(item)
+    for item in seq:
+        key = func(item)
         if key not in d:
             d[key] = []
         d[key].append(item)
     return d
 
 
-def merge_sorted(*iters, **kwargs):
+def merge_sorted(*seqs, **kwargs):
     """ Merge and sort a collection of sorted collections
 
     This works lazily and only keeps one value from each iterable in memory.
@@ -88,7 +88,7 @@ def merge_sorted(*iters, **kwargs):
     key = kwargs.get('key', None)
     if key is None:
         # heapq.merge does what we do below except by val instead of key(val)
-        for item in heapq.merge(*iters):
+        for item in heapq.merge(*seqs):
             yield item
     else:
         # The commented code below shows an alternative (slower) implementation
@@ -96,14 +96,14 @@ def merge_sorted(*iters, **kwargs):
         #
         # mapper = lambda i, item: (key(item), i, item)
         # keyiters = [map(partial(mapper, i), itr) for i, itr in
-        #             enumerate(iters)]
+        #             enumerate(seqs)]
         # return (item for (item_key, i, item) in heapq.merge(*keyiters))
 
         # binary heap as a priority queue
         pq = []
 
         # Initial population
-        for itnum, it in enumerate(map(iter, iters)):
+        for itnum, it in enumerate(map(iter, seqs)):
             try:
                 item = next(it)
                 pq.append([key(item), itnum, item, it])
@@ -174,16 +174,6 @@ def unique(seq, key=identity):
             yield item
 
 
-def intersection(*seqs):
-    """ Lazily evaluated intersection of sequences
-
-    >>> list(intersection([1, 2, 3], [2, 3, 4]))
-    [2, 3]
-    """
-    return (item for item in seqs[0]
-            if all(item in seq for seq in seqs[1:]))
-
-
 def isiterable(x):
     """ Is x iterable?
 
@@ -243,6 +233,15 @@ def drop(n, seq):
     return itertools.islice(seq, n, None)
 
 
+def take_nth(n, seq):
+    """ Every nth item in seq
+
+    >>> list(take_nth(2, [10, 20, 30, 40, 50]))
+    [10, 30, 50]
+    """
+    return itertools.islice(seq, 0, None, n)
+
+
 def first(seq):
     """ The first element in a sequence
 
@@ -267,9 +266,9 @@ def nth(n, seq):
     >>> nth(1, 'ABC')
     'B'
     """
-    try:
+    if isinstance(seq, (tuple, list, collections.Sequence)):
         return seq[n]
-    except TypeError:
+    else:
         return next(itertools.islice(seq, n, None))
 
 
@@ -377,14 +376,14 @@ def concatv(*seqs):
     return concat(seqs)
 
 
-def mapcat(f, seqs):
-    """ Apply f to each sequence in seqs, concatenating results
+def mapcat(func, seqs):
+    """ Apply func to each sequence in seqs, concatenating results.
 
     >>> list(mapcat(lambda s: [c.upper() for c in s],
     ...             [["a", "b"], ["c", "d", "e"]]))
     ['A', 'B', 'C', 'D', 'E']
     """
-    return concat(map(f, seqs))
+    return concat(map(func, seqs))
 
 
 def cons(el, seq):
@@ -404,7 +403,8 @@ def interpose(el, seq):
     >>> list(interpose("a", [1, 2, 3]))
     [1, 'a', 2, 'a', 3]
     """
-    return rest(mapcat(lambda x: [el, x], seq))
+    combined = zip(itertools.repeat(el), seq)
+    return drop(1, concat(combined))
 
 
 def frequencies(seq):
@@ -426,19 +426,19 @@ def frequencies(seq):
     return d
 
 
-def reduceby(keyfn, binop, seq, init):
+def reduceby(key, binop, seq, init):
     """ Perform a simultaneous groupby and reduction
 
     The computation:
 
-    >>> result = reduceby(keyfn, binop, seq, init)      # doctest: +SKIP
+    >>> result = reduceby(key, binop, seq, init)      # doctest: +SKIP
 
     is equivalent to the following:
 
     >>> def reduction(group):                           # doctest: +SKIP
     ...     return reduce(binop, group, init)           # doctest: +SKIP
 
-    >>> groups = groupby(keyfn, seq)                    # doctest: +SKIP
+    >>> groups = groupby(key, seq)                    # doctest: +SKIP
     >>> result = valmap(reduction, groups)              # doctest: +SKIP
 
     But the former does not build the intermediate groups, allowing it to
@@ -464,17 +464,17 @@ def reduceby(keyfn, binop, seq, init):
     """
     d = {}
     for item in seq:
-        key = keyfn(item)
-        if key not in d:
-            d[key] = init
-        d[key] = binop(d[key], item)
+        k = key(item)
+        if k not in d:
+            d[k] = init
+        d[k] = binop(d[k], item)
     return d
 
 
-def iterate(f, x):
-    """ Repeatedly apply a function f onto an original input
+def iterate(func, x):
+    """ Repeatedly apply a function func onto an original input
 
-    Yields x, then f(x), then f(f(x)), then f(f(f(x))), etc..
+    Yields x, then func(x), then func(func(x)), then func(func(func(x))), etc..
 
     >>> def inc(x):  return x + 1
     >>> counter = iterate(inc, 0)
@@ -499,7 +499,7 @@ def iterate(f, x):
     """
     while True:
         yield x
-        x = f(x)
+        x = func(x)
 
 
 def sliding_window(n, seq):
@@ -518,6 +518,8 @@ def sliding_window(n, seq):
     it = iter(seq)
     # An efficient FIFO data structure with maximum length
     d = collections.deque(itertools.islice(it, n), n)
+    if len(d) != n:
+        raise StopIteration()
     for item in it:
         yield tuple(d)
         d.append(item)
@@ -588,4 +590,6 @@ def count(seq):
     See also:
         len
     """
+    if hasattr(seq, '__len__'):
+        return len(seq)
     return sum(1 for i in seq)
